pub struct Bomb {
payload: Option<Box<dyn FnOnce() -> String>>,
}Expand description
A Bomb instance will panic if it is not Bomb::diffused.
Add a Bomb to your type to make sure that something happens before
the type (and thus bomb) is dropped.
Fields
payload: Option<Box<dyn FnOnce() -> String>>Implementations